==> digikam_0.7.orig.tar.gz: digikam-0.7/digikam/utilities/imageeditor/imagewindow.h <==
/* ============================================================
 * File  : imagewindow.h
 * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
 *         Gilles Caulier <caulier dot gilles at free.fr>
 * Date  : 2004-02-12
 * Description : 
 * 
 * Copyright 2004 by Renchi Raju, Gilles Caulier
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published bythe Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef IMAGEWINDOW_H
#define IMAGEWINDOW_H

// Qt includes.

#include <qmainwindow.h>
#include <qstring.h>

// Kde includes.

#include <kurl.h>
#include <kio/job.h>

class QPopupMenu;
class QLabel;
class KAccel;
class KAction;

class ImageGUIClient;
class Canvas;

namespace Digikam
{
class GUIFactory;
}

class ImageWindow : public QMainWindow
{
    Q_OBJECT

public:

    ~ImageWindow();

    void loadURL(const KURL::List& urlList, const KURL& urlCurrent,
                 const QString& caption=QString::null,
                 bool allowSaving=true);
    void applySettings();
    
    static ImageWindow* instance();
    
private:

    ImageGUIClient*      m_guiClient;
    Digikam::GUIFactory* m_guiFactory;
    Canvas*              m_canvas;
    QPopupMenu*          m_contextMenu;
    KAccel*              m_accel;

    QLabel*              m_nameLabel;
    QLabel*              m_zoomLabel;
    QLabel*              m_resLabel;
    
    KURL::List           m_urlList;
    KURL                 m_urlCurrent;
    KURL                 m_newFile;
    
    bool                 m_rotatedOrFlipped;
    
    bool                 m_fullScreen;
    bool                 m_fullScreenHideToolBar;
    bool                 m_allowSaving;
    
    int                  m_JPEGCompression;
    
    static ImageWindow*  m_instance;

private:

    ImageWindow();
    void readSettings();
    void saveSettings();
    void promptUserSave();
    void plugActionAccel(KAction* action);
    void unplugActionAccel(KAction* action);

signals:

    void signalFileDeleted(const KURL& url);
    void signalFileAdded(const KURL& url);
    void signalFileModified(const KURL& url);
    
private slots:

    void slotLoadCurrent();
    
    void slotLoadNext();
    void slotLoadPrev();
    void slotLoadFirst();
    void slotLoadLast();

    void slotToggleAutoZoom();
    void slotToggleFullScreen();
    void slotEscapePressed();

    void slotResize();
    void slotRotate();
    
    void slotContextMenu();
    void slotZoomChanged(float zoom);
    void slotChanged(bool);
    void slotSelected(bool);

    void slotRotatedOrFlipped();
    
    void slotSave();
    void slotSaveAs();
    void slotSaveAsResult(KIO::Job *job);
    
    void slotFilePrint();
    void slotFileProperties();
    void slotExifInfo();
    void slotCommentsEdit();
    
    void slotDeleteCurrentItem();

    void slotImagePluginsHelp();
    
protected:

    void closeEvent(QCloseEvent *e);

};

#endif /* IMAGEWINDOW_H */

==> digikam_0.7.2.orig.tar.gz: digikam-0.7.2/digikam/utilities/imageeditor/imagewindow.h <==
/* ============================================================
 * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
 *         Gilles Caulier <caulier dot gilles at free.fr>
 * Date  : 2004-02-12
 * Description : 
 * 
 * Copyright 2004 by Renchi Raju, Gilles Caulier
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef IMAGEWINDOW_H
#define IMAGEWINDOW_H

// Qt includes.

#include <kmainwindow.h>
#include <qstring.h>

// Kde includes.

#include <kurl.h>
#include <kio/job.h>

class QPopupMenu;
class QLabel;

class KAccel;
class KAction;
class KActionMenu;
class KToggleAction;

class Canvas;
class AlbumIconView;

class ImageWindow : public KMainWindow
{
    Q_OBJECT

public:

    ~ImageWindow();

    void loadURL(const KURL::List& urlList, const KURL& urlCurrent,
                 const QString& caption=QString::null,
                 bool allowSaving=true,
                 AlbumIconView* view=0L);
                 
    void applySettings();
    
    static ImageWindow* imagewindow();
    
private:

    Canvas*              m_canvas;
    
    QPopupMenu*          m_contextMenu;
    
    KAccel*              m_accel;

    QLabel*              m_nameLabel;
    QLabel*              m_zoomLabel;
    QLabel*              m_resLabel;
    
    KURL::List           m_urlList;
    KURL                 m_urlCurrent;
    KURL                 m_newFile;
    
    // Allow to use Image properties and Comments/Tags dialogs from main window.
    AlbumIconView*       m_view;
    
    int                  m_JPEGCompression;
    int                  m_PNGCompression;
    
    bool                 m_TIFFCompression;
    bool                 m_rotatedOrFlipped;
    bool                 m_fullScreen;
    bool                 m_fullScreenHideToolBar;
    bool                 m_allowSaving;

    // Actions

    KAction       *m_navNextAction;
    KAction       *m_navPrevAction;
    KAction       *m_navFirstAction;
    KAction       *m_navLastAction;

    KAction       *m_saveAction;
    KAction       *m_saveAsAction;
    KAction       *m_restoreAction;
    
    KAction       *m_zoomPlusAction;
    KAction       *m_zoomMinusAction;
    KToggleAction *m_zoomFitAction;
    KToggleAction *m_fullScreenAction;

    KActionMenu   *m_rotateAction;
    KActionMenu   *m_flipAction;
    KAction       *m_rotate90Action;
    KAction       *m_rotate180Action;
    KAction       *m_rotate270Action;
    KAction       *m_flipHorzAction;
    KAction       *m_flipVertAction;

    KAction       *m_resizeAction;
    KAction       *m_cropAction;
    
    KAction       *m_fileprint;    
    KAction       *m_fileproperties;
    KAction       *m_fileDelete;
    KAction       *m_commentedit;
    
    KAction       *m_copyAction;
    KAction       *m_undoAction;
    
    KAction       *m_imagePluginsHelp;
    
    static ImageWindow*  m_instance;

private:

    ImageWindow();
    void buildGUI();
    void readSettings();
    void saveSettings();
    bool promptUserSave();
    void plugActionAccel(KAction* action);
    void unplugActionAccel(KAction* action);
    bool save();

signals:

    void signalFileDeleted(const KURL& url);
    void signalFileAdded(const KURL& url);
    void signalFileModified(const KURL& url);
    
private slots:

    void slotLoadCurrent();
    
    void slotLoadNext();
    void slotLoadPrev();
    void slotLoadFirst();
    void slotLoadLast();

    void slotToggleAutoZoom();
    void slotToggleFullScreen();
    void slotEscapePressed();

    void slotResize();
    
    void slotContextMenu();
    void slotZoomChanged(float zoom);
    void slotChanged(bool);
    void slotSelected(bool);

    void slotRotatedOrFlipped();
    
    void slotSave();
    void slotSaveAs();
    void slotSaveAsResult(KIO::Job *job);
    
    void slotFilePrint();
    void slotFileProperties();
    void slotCommentsEdit();
    
    void slotDeleteCurrentItem();

    void slotImagePluginsHelp();

    void slotEditKeys();
    void slotConfToolbars();
    void slotNewToolbarConfig();
    
protected:

    void closeEvent(QCloseEvent *e);

};

#endif /* IMAGEWINDOW_H */
